# Resik 0.0.5

This is a interface for show menssages 
```py
python -m resik
```

# install the lasted version available 

command
```py
pip install resik==0.x.x
```

example 

```py
pip install resik==0.0.1
```